from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, Int, Directory, File, Boolean, Float

Strainphlan_Py_V0_1_0 = CommandToolBuilder(tool="strainphlan.py", base_command=["strainphlan.py"], inputs=[ToolInput(tag="in_ifn_samples", input_type=Array(t=String(), optional=True), prefix="--ifn_samples", doc=InputDocumentation(doc="The list of sample files (space separated).The\nwildcard can also be used.")), ToolInput(tag="in_ifn_second_samples", input_type=Array(t=String(), optional=True), prefix="--ifn_second_samples", doc=InputDocumentation(doc="The list of second sample files (space separated).The\nwildcard can also be used. Note that only the markers\nfound in the samples or reference genomes specified by\n--ifn_samples or --ifn_representative_sample or\n--ifn_ref_genomes with\nadd_reference_genomes_as_second_samples=False will be\nused to build the phylogenetic trees.")), ToolInput(tag="in_ifn_representative_sample", input_type=String(optional=True), prefix="--ifn_representative_sample", doc=InputDocumentation(doc="The representative sample. The marker list of each\nspecies extracted from this sample will be used for\nall other samples.")), ToolInput(tag="in_index", input_type=Int(optional=True), prefix="--index", doc=InputDocumentation(doc="Specify the id of the database version to use. If the\ndatabase files are not found on the local MetaPhlAn2\ninstallation they will be automatically downloaded")), ToolInput(tag="in_mpa_pkl", input_type=Int(optional=True), prefix="--mpa_pkl", doc=InputDocumentation(doc="The database of metaphlan2.py")), ToolInput(tag="in_output_dir", input_type=Directory(optional=True), prefix="--output_dir", doc=InputDocumentation(doc="The output directory.")), ToolInput(tag="in_ifn_markers", input_type=File(optional=True), prefix="--ifn_markers", doc=InputDocumentation(doc="The marker file in fasta format.")), ToolInput(tag="in_nprocs_main", input_type=Int(optional=True), prefix="--nprocs_main", doc=InputDocumentation(doc="The number of processors are used for the main\nthreads. Default 1.")), ToolInput(tag="in_nprocs_load_samples", input_type=Int(optional=True), prefix="--nprocs_load_samples", doc=InputDocumentation(doc="The number of processors are used for loading samples.\nDefault nprocs_main.")), ToolInput(tag="in_nprocs_align_clean", input_type=Int(optional=True), prefix="--nprocs_align_clean", doc=InputDocumentation(doc="The number of processors are used for aligning and\ncleaning markers. Default nprocs_main.")), ToolInput(tag="in_nprocs_ra_xml", input_type=Int(optional=True), prefix="--nprocs_raxml", doc=InputDocumentation(doc="The number of processors are used for running raxml.\nDefault nprocs_main.")), ToolInput(tag="in_bootstrap_ra_xml", input_type=Int(optional=True), prefix="--bootstrap_raxml", doc=InputDocumentation(doc="The number of runs for bootstraping when building the\ntree. Default 0.")), ToolInput(tag="in_ifn_ref_genomes", input_type=Array(t=String(), optional=True), prefix="--ifn_ref_genomes", doc=InputDocumentation(doc="The reference genome file names. They are separated by\nspaces.")), ToolInput(tag="in_add_reference_genomes_as_second_samples", input_type=Boolean(optional=True), prefix="--add_reference_genomes_as_second_samples", doc=InputDocumentation(doc="Add reference genomes as second samples. Default\n'False'. Note that only the markers found in the\nsamples or reference genomes specified by\n--ifn_samples or --ifn_representative_sample or\n--ifn_ref_genomes with\nadd_reference_genomes_as_second_samples=False will be\nused to build the phylogenetic trees.")), ToolInput(tag="in_n_in_marker", input_type=Float(optional=True), prefix="--N_in_marker", doc=InputDocumentation(doc="The consensus markers with the rate of N nucleotides\ngreater than this threshold are removed. Default 0.2.")), ToolInput(tag="in_marker_strip_length", input_type=Int(optional=True), prefix="--marker_strip_length", doc=InputDocumentation(doc="The number of nucleotides will be deleted from each of\ntwo ends of a marker. Default 50.")), ToolInput(tag="in_marker_in_clade", input_type=Float(optional=True), prefix="--marker_in_clade", doc=InputDocumentation(doc="In each sample, the clades with the rate of present\nmarkers less than this threshold are removed. Default\n0.8.")), ToolInput(tag="in_second_marker_in_clade", input_type=Float(optional=True), prefix="--second_marker_in_clade", doc=InputDocumentation(doc="In each sample/reference genomes specified by\n--ifn_second_samples, or\n--add_reference_genomes_as_second_samples, the clades\nwith the rate of present markers less than this\nthreshold are removed. Default 0.8.")), ToolInput(tag="in_sample_in_clade", input_type=Int(optional=True), prefix="--sample_in_clade", doc=InputDocumentation(doc="Only clades present in at least sample_in_clade\nsamples are kept. Default 2.")), ToolInput(tag="in_sample_in_marker", input_type=Float(optional=True), prefix="--sample_in_marker", doc=InputDocumentation(doc="If the percentage of samples that a marker present in\nis less than this threshold, that marker is removed.\nDefault 0.8.")), ToolInput(tag="in_gap_in_trailing_col", input_type=Int(optional=True), prefix="--gap_in_trailing_col", doc=InputDocumentation(doc="If the number of the trailing nucleotide columns in\naligned markers with the percentage of gaps greater\nthan gap_in_trailing_col is less than\ngap_trailing_col_limit, these columns will be removed.\nDefault 0.2.")), ToolInput(tag="in_gap_trailing_col_limit", input_type=Int(optional=True), prefix="--gap_trailing_col_limit", doc=InputDocumentation(doc="If the number of the trailing nucleotide columns in\naligned markers with the percentage of gaps greater\nthan gap_in_trailing_col is less than\ngap_trailing_col_limit, these columns will be removed.\nDefault 101.")), ToolInput(tag="in_gap_in_internal_col", input_type=Float(optional=True), prefix="--gap_in_internal_col", doc=InputDocumentation(doc="The internal nucleotide columns in aligned markers\nwith the percentage of gaps greater than\ngap_in_internal_col will be removed. Default 0.3.")), ToolInput(tag="in_gap_in_sample", input_type=Float(optional=True), prefix="--gap_in_sample", doc=InputDocumentation(doc="The samples with full sequences from all markers and\nhaving the percentage of gaps greater than this\nthreshold will be removed. Default 0.2.")), ToolInput(tag="in_second_gap_in_sample", input_type=Float(optional=True), prefix="--second_gap_in_sample", doc=InputDocumentation(doc="The samples specified by --ifn_second_samples with\nfull sequences from all markers and having the\npercentage of gaps greater than this threshold will be\nremoved. Default 0.2.")), ToolInput(tag="in_n_col", input_type=Float(optional=True), prefix="--N_col", doc=InputDocumentation(doc="In aligned markers, if the percentage of nucleotide\ncolumns containing more than N_count Ns less than this\nthreshold, these columns will be removed. Default 0.8.")), ToolInput(tag="in_n_count", input_type=Int(optional=True), prefix="--N_count", doc=InputDocumentation(doc="In aligned markers, if the percentage of nucleotide\ncolumns containing more than N_count Ns less than\nN_col threshold, these columns will be removed.\nDefault 0.")), ToolInput(tag="in_long_gap_length", input_type=Int(optional=True), prefix="--long_gap_length", doc=InputDocumentation(doc="In each concatenated sequence of a sample, sequential\ngap positions is a gap group. A gap group with length\ngreater than this threshold is considered as a long\ngap group. If the ratio between the number of unique\npositions in all long gap groups and the concatenated\nsequence length is less than long_gap_percentage,\nthese positions will be removed from all concatenated\nsequences. Default 2.")), ToolInput(tag="in_long_gap_percentage", input_type=Float(optional=True), prefix="--long_gap_percentage", doc=InputDocumentation(doc="Combining this threshold with long_gap_length to\nremoved long gaps. Default 0.8.")), ToolInput(tag="in_p_value", input_type=String(optional=True), prefix="--p_value", doc=InputDocumentation(doc="The p_value to reject a non-polymorphic site.Default")), ToolInput(tag="in_marker_list_fn", input_type=File(optional=True), prefix="--marker_list_fn", doc=InputDocumentation(doc="The file name containing the list of considered\nmarkers. The other markers will be discarded. Default\n'None'.")), ToolInput(tag="in_print_clades_only", input_type=Boolean(optional=True), prefix="--print_clades_only", doc=InputDocumentation(doc="Only print the potential clades and stop without\nbuilding any tree. This option is useful when you want\nto check quickly all possible clades and rerun only\nfor some specific ones. Default 'False'.")), ToolInput(tag="in_alignment_program", input_type=String(optional=True), prefix="--alignment_program", doc=InputDocumentation(doc="The alignment program. Default 'muscle'.")), ToolInput(tag="in_relaxed_parameters", input_type=Boolean(optional=True), prefix="--relaxed_parameters", doc=InputDocumentation(doc="Set marker_in_clade=0.5, sample_in_marker=0.5,\nN_in_marker=0.5, gap_in_sample=0.5. Default 'False'.")), ToolInput(tag="in_relaxed_parameters_two", input_type=Boolean(optional=True), prefix="--relaxed_parameters2", doc=InputDocumentation(doc="Set marker_in_clade=0.2, sample_in_marker=0.2,\nN_in_marker=0.8, gap_in_sample=0.8. Default 'False'.")), ToolInput(tag="in_relaxed_parameters_three", input_type=Boolean(optional=True), prefix="--relaxed_parameters3", doc=InputDocumentation(doc="Set gap_in_trailing_col=0.9, gap_in_internal_col=0.9,\ngap_in_sample=0.9, second_gap_in_sample=0.5,\nsample_in_marker=0.1, marker_in_clade=0.1,\nsecond_marker_in_clade=0.1, Default 'False'.")), ToolInput(tag="in_keep_alignment_files", input_type=Boolean(optional=True), prefix="--keep_alignment_files", doc=InputDocumentation(doc="Keep the alignment files of all markers before\ncleaning step.")), ToolInput(tag="in_keep_full_alignment_files", input_type=Boolean(optional=True), prefix="--keep_full_alignment_files", doc=InputDocumentation(doc="Keep the alignment files of all markers before\ntruncating the starting and ending parts, and cleaning\nstep. This is equivalent to --keep_alignment_files\n--marker_strip_length 0")), ToolInput(tag="in_save_sample_two_full_freq", input_type=Boolean(optional=True), prefix="--save_sample2fullfreq", doc=InputDocumentation(doc="Save sample2fullfreq to a msgpack file\nsample2fullfreq.msgpack.")), ToolInput(tag="in_use_threads", input_type=Boolean(optional=True), prefix="--use_threads", doc=InputDocumentation(doc="Use multithreading. Default 'Use multiprocessing'.")), ToolInput(tag="in_zero_dot_zero_five_dot", input_type=Float(), position=0, doc=InputDocumentation(doc="--clades CLADES [CLADES ...]"))], outputs=[ToolOutput(tag="out_output_dir", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_output_dir", type_hint=File()), doc=OutputDocumentation(doc="The output directory."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Strainphlan_Py_V0_1_0().translate("wdl", allow_empty_container=True)

